========================
duffie2013
========================

.. {# pkglts, doc

.. image:: https://revesansparole.gitlab.io/duffie2013/_images/badge_doc.svg
    :alt: Documentation status
    :target: https://revesansparole.gitlab.io/duffie2013/

.. image:: https://revesansparole.gitlab.io/duffie2013/_images/badge_pkging_pip.svg
    :alt: PyPI version
    :target: https://pypi.org/project/duffie2013/0.1.1/

.. image:: https://revesansparole.gitlab.io/duffie2013/_images/badge_pkging_conda.svg
    :alt: Conda version
    :target: https://anaconda.org/revesansparole/duffie2013

.. image:: https://badge.fury.io/py/duffie2013.svg
    :alt: PyPI version
    :target: https://badge.fury.io/py/duffie2013

.. #}
.. {# pkglts, glabpkg, after doc

develop: |dvlp_build|_ |dvlp_coverage|_

.. |dvlp_build| image:: https://gitlab.com/revesansparole/duffie2013/badges/develop/pipeline.svg
.. _dvlp_build: https://gitlab.com/revesansparole/duffie2013/commits/develop

.. |dvlp_coverage| image:: https://gitlab.com/revesansparole/duffie2013/badges/develop/coverage.svg
.. _dvlp_coverage: https://gitlab.com/revesansparole/duffie2013/commits/develop


master: |master_build|_ |master_coverage|_

.. |master_build| image:: https://gitlab.com/revesansparole/duffie2013/badges/master/pipeline.svg
.. _master_build: https://gitlab.com/revesansparole/duffie2013/commits/master

.. |master_coverage| image:: https://gitlab.com/revesansparole/duffie2013/badges/master/coverage.svg
.. _master_coverage: https://gitlab.com/revesansparole/duffie2013/commits/master
.. #}

Implementation of formalisms from Duffie 2013 on solar engineering

